ts-io
Structs
- Base64
Url - Bytes that (de)serialize to
unpadded base64url. - Cursor
- A simple cursor over a slice.
- Item
Formatter - A wrapper struct to display a collections items.
- OutOf
Bounds - A read would take the cursor out of bounds.
Enums
- Child
Command Error - Error variants for using a child command.
- File
Error - Error variants for interacting with a file.
Traits
- AsItem
Formatter - Trait to interpret a collection as an item formatter.
- Display
Path - Extension trait to display a path.
- Iterable
- Trait to mark a struct as iterable over
Item. - Normalize
Path - Extension trait to call [
crate::normalize_path] on a path. - Relative
Path - Extension trait to get the relative path.
Functions
- ensure_
is_ file - Return
Ok(())if a path points to a file. - process_
using_ child - Write
datato a child process’stdin, and return the process’stdoutandstderr. - read_
file - Read a file, returning presentable error variants.
- read_
file_ to_ string - Read a file to a string, returning presentable error variants.