pub trait NormalizePath {
// Required method
fn normalized(&self) -> PathBuf;
}Expand description
Extension trait to call [crate::normalize_path] on a path.
Required Methods
Sourcefn normalized(&self) -> PathBuf
fn normalized(&self) -> PathBuf
Normalize a path using only the components of the path.
This will ignore any symbolic links, and strip the verbatim \\?\ prefixes, so should only be
used when that can be tolerated.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".