NormalizePath

Trait NormalizePath 

pub trait NormalizePath {
    // Required method
    fn normalized(&self) -> PathBuf;
}
Extension trait to call [crate::normalize_path] on a path.

Required Methods

fn normalized(&self) -> PathBuf

Normalize a path using only the components of the path.

This will ignore any symbolic links, and strip the verbatim \\?\ prefixes, so should only be used when that can be tolerated.

Implementors